@@ -141,7 +141,7 @@ Group by StressVowel) AS averages""",[self.pk])
                 continue
             allout.extend(w.getAnalysisLines(form))
             if settings.DEBUG:
-                print outline[-1]
+                print allout[-1]
         return allout
 
     def load_dialogs(self):
